@@ -1,9 +1,11 @@
-import sys
 import os
+import sys
+
 from django.conf import settings
 
-from easymode.i18n import meta
 from easymode import i18n
+from easymode.i18n import meta
+
 
 class I18n(object):
     """
@@ -35,15 +37,3 @@ class I18n(object):
         cls._meta.permissions.append(("can_edit_global_fields", "Can edit restricted fields"))
 
         return cls
-    
-def L10n_CMS(*localized_fields):
-
-    def modify_class(cls):
-        model_dir = os.path.join(settings.PROJECT_DIR, 'cms' + getattr(settings, 'LOCALE_POSTFIX', ''))
-        cls = meta.localize_cms_stuff_fields(cls, *localized_fields)
-        if getattr(settings, 'AUTO_CATALOG', True):
-            i18n.register(cls, getattr(settings, 'LOCALE_DIR', None) or model_dir)
-        
-        return cls
-        
-    return modify_class
